==> nextcloud-26.0.7p0.tgz: nextcloud/apps/settings/l10n/az.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Gizli",
    "Local" : "Yerli",
    "Federated" : "Federated",
    "Published" : "Nəşr edilmiş",
    "Verify" : "Təsdiq et",
    "Verifying …" : "Təsdiqlənir ...",
    "Unable to change password" : "Şifrəni dəyişmək olmur",
    "Very weak password" : "Çox asan şifrə",
    "Weak password" : "Asan şifrə",
    "So-so password" : "Elə-belə şifrə",
    "Good password" : "Yaxşı şifrə",
    "Strong password" : "Çətin şifrə",
    "Groups" : "Qruplar",
    "Group list is empty" : "Qrup listi boşdur",
    "Your password was reset" : "Sizin parol yeniləndi",
    "You changed your email address" : "Siz email ünvanınızı dəyişdir",
    "Apps" : "Tətbiqlər",
    "Could not remove app." : "Tətbiqi silmək olmur.",
    "Could not update app." : "Tətbiqi yeniləmək alınmır",
    "Wrong password" : "Yalnış şifrə",
    "Unable to change personal password" : "Şəxsi parolu dəyişmək alınmadı",
    "Saved" : "Saxlanıldı",
    "No user supplied" : "Heç bir istifadəçiyə mənimsədilmir",
    "Unable to change password. Password too long." : "Parolu dəyişmək alınmadı. Parol çox uzundur.",
    "Authentication error" : "Təyinat metodikası",
    "Wrong admin recovery password. Please check the password and try again." : "İnzibatçı geriyə qayıdış şifrəsi yalnışdır. Xahiş olunur şifrəni yoxlayıb yenidən təkrar edəsiniz.",
    "Federated Cloud Sharing" : "Federal Cloud Paylaşım",
    "User documentation" : "İstifadəçi dokumentasiyası",
    "Invalid SMTP password." : "SMTP parol səhvdir",
    "Email setting test" : "Email parametrləriinin testi",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Məktubun yollanmasında səhv baş verdi. Xahiş olunur öz quraşdırmalarınıza yenidən göz yetirəsiniz.(Error: %s)",
    "Users" : "İstifadəçilər",
    "Invalid user" : "İstifadəçi adı yalnışdır",
    "Invalid mail address" : "Yalnış mail ünvanı",
    "Settings saved" : "Parametrlər yaddaşa verildi",
    "Unable to change full name" : "Tam adı dəyişmək olmur",
    "Your %s account was created" : "Sizin %s hesab yaradıldı",
    "Set your password" : "Parolunuzu təyin edin",
    "Install Client" : "Müştərini Quraşdır",
    "Settings" : "Quraşdırmalar",
    "Personal" : "Şəxsi",
    "Administration" : "İdarəetmə",
    "Additional settings" : "Əlavə parametrlər",
    "Overview" : "İcmal",
    "Basic settings" : "İlkin parametrlər",
    "Sharing" : "Paylaşılır",
    "Availability" : "Əlçatanlıq",
    "Calendar" : "Təqvim",
    "Personal info" : "Şəxsi məlumat",
    "Mobile & desktop" : "Mobil & Desktop",
    "Email server" : "Email server",
    "Security & setup warnings" : "Təhlükəsizlik & işə salma xəbərdarlıqları",
    "Background jobs" : "Background işlər",
    "Create" : "Yarat",
    "Change" : "Dəyiş",
    "Delete" : "Sil",
    "Unlimited" : "Limitsiz",
    "Verifying" : "Təsdiqlənir",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Server tərəfdən köhnə şifrələnmə formatı aktivdir. Onu söndürməyi tövsiyyə edirik.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB \"%s\" versiyası istifadə edilir. Nextcloud 21 və yuxarı versiyaları bunu dəstəkləmir və ən azı MariaDB 10.2 və ya yuxarı versiya tələb edir.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL \"%s\" versiyası istifadə edilir. Nextcloud 21 və yuxarı versiyaları bunu dəstəkləmir və ən azı MySQL 8.0 və ya MariaDB 10.2 və ya yuxarı versiya tələb edir.",
    "Profile information" : "Profil məlumatı",
    "Nextcloud settings" : "Nextcloud parametrləri",
    "None" : "Heç bir",
    "Unable to modify setting" : "Xassələri yeniləmək olmadı",
    "Two-Factor Authentication" : "İki faktorlu autentifikasiya",
    "Limit to groups" : "Qruplara limitlə",
    "Save changes" : "Dəyişiklikləri yaddaşa ver",
    "All" : "Hamısı",
    "Limit app usage to groups" : "Tətbiqin istifadəsini qruplar üçün limitlə",
    "No results" : "Nəticə yoxdur",
    "Update to {version}" : "{version} dək yenilə",
    "Remove" : "Sil",
    "Disable" : "Dayandır",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Bu proqram yüklənə bilməz ona görə ki, göstərilən asılılıqlar yerinə yetirilməyib:",
    "View in store" : "Dükanda bax",
    "Visit website" : "Sayta keç",
    "Report a bug" : "Səhv haqqında bildir",
    "Admin documentation" : "İdarəci dokumentasiyası",
    "Developer documentation" : "Yaradıcı sənədləşməsi",
    "Supported" : "Dəstəklənir",
    "Featured" : "Seçilmiş",
    "Name" : "Ad",
    "Version" : "Versiya",
    "Actions" : "İşlər",
    "No apps found for your version" : "Sizin versiya üçün proqram tapılmadı",
    "Device settings" : "Cihazın parametrləri",
    "Rename" : "Adı dəyiş",
    "Wipe device" : "Cihazı silin",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Android üçün Google Chrome",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOS tətbiq",
    "{productName} Android app" : "{productName} Android tətbiq",
    "{productName} Talk for iOS" : "{productName} iOS üçün danış",
    "{productName} Talk for Android" : "{productName} Android üçün danış",
    "This session" : "Bu sessiya",
    "Device" : "Cihaz",
    "Last activity" : "Son aktivlik",
    "Devices & sessions" : "Cihaz & sessiyalar",
    "Confirm wipe" : "Silməni təsdiq edin",
    "Error while updating device token name" : "Cihazın tokeninin adını yeniləyən vaxtı səhv baş verdi",
    "Error while deleting the token" : "Token silinən vaxtı səhv baş verdi",
    "App name" : "Tətbiqin adı",
    "Create new app password" : "Yeni tətbiq parolu yaradın",
    "Username" : "İstifadəçi adı",
    "Password" : "Şifrə",
    "Done" : "Edildi",
    "Show QR code for mobile apps" : "Mobil tətbiqlər üçün QR kodu göstərin",
    "Copied!" : "Kopyalandı!",
    "Copy" : "Kopyala",
    "Last job ran {relativeTime}." : "Son işin icra vaxtı {relativeTime}.",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (Tövsiyyə edilən)",
    "Profile" : "Profil",
    "Enable" : "İşə sal",
    "Rename group" : "Qrupun adını dəyiş",
    "Remove group" : "Qrupu sil",
    "Current password" : "Hazırkı şifrə",
    "New password" : "Yeni şifrə",
    "Change password" : "Şifrəni dəyiş",
    "Your profile information" : "Sizin profil məlumatlarınız",
    "Your profile picture" : "Sizin profil şəkliniz",
    "Upload profile picture" : "Profil şəklini yüklə",
    "Choose profile picture from Files" : "Profil şəklini Faylalrdan seçin",
    "Remove profile picture" : "Profil şəklini silin",
    "The file must be a PNG or JPG" : "Fayl PNG və ya JPG olmalıdır",
    "Cancel" : "Dayandır",
    "Set as profile picture" : "Profil şəkli kimi təyin et",
    "Please select a valid png or jpg file" : "Zəhmət olmasa düzgün png və ya jpg fayl seçin",
    "Error setting profile picture" : "Profil şəklini təyiin edən vaxtı səhv baş verdi",
    "Error saving profile picture" : "Profil şəklini saxlayan vaxtı səhv baş verdi",
    "Error removing profile picture" : "Profil şəklini silən vaxtı səhv baş verdi",
    "Details" : "Detallar",
    "Your email address" : "Sizin email ünvanı",
    "No email address set" : "Email ünvanı dəsti yoxdur",
    "Language" : "Dil",
    "Help translate" : "Tərcüməyə kömək",
    "Add" : "Əlavə etmək",
    "Email" : "Email",
    "Quota" : "Norma",
    "Edit" : "Dəyişiklik et",
    "Show user backend" : "Daxili istifadəçini göstər",
    "Send email" : "Email yolla",
    "Admins" : "İnzibatçılar",
    "Email sent" : "Məktub göndərildi",
    "Location" : "Yerləşdiyiniz ünvan",
    "Profile picture" : "Profil şəkli",
    "About" : "Haqqında",
    "Full name" : "Tam ad",
    "Updates" : "Yenilənmələr",
    "Hide" : "Gizlə",
    "Never" : "Heç vaxt",
    "Documentation" : "Sənədlər",
    "Forum" : "Forum",
    "Login" : "Giriş",
    "SSL" : "SSL",
    "Open documentation" : "Sənədləri aç",
    "Send mode" : "Göndərmə rejimi",
    "Encryption" : "Şifrələnmə",
    "From address" : "Ünvandan",
    "Server address" : "Server ünvanı",
    "Port" : "Port",
    "Authentication required" : "Qeydiyyat tələb edilir",
    "Credentials" : "Səlahiyyətlər",
    "SMTP Username" : "SMTP İstifadəçi adı",
    "SMTP Password" : "SMTP Şifrəsi",
    "Save" : "Saxla",
    "Allow apps to use the Share API" : "Proqramlara izin verin ki, Paylaşım API-sindən istifadə edə bilsinlər.",
    "Enforce expiration date" : "Bitmə tarixini həyata keçir",
    "Allow public uploads" : "Ümumi yüklənmələrə izin vermək",
    "Enforce password protection" : "Şifrə müdafiəsini həyata keçirmək",
    "Set default expiration date" : "Susmaya görə olan bitmə vaxtını təyin edin",
    "Allow resharing" : "Yenidən paylaşıma izin",
    "Restrict users to only share with users in their groups" : "İstifadəçiləri yalnız yerləşdikləri qrup üzvləri ilə paylaşım edə bilmələrini məhdudla",
    "Exclude groups from sharing" : "Qrupları paylaşımdan ayır",
    "These groups will still be able to receive shares, but not to initiate them." : "Bu qruplar paylaşımları hələdə ala biləcəklər ancaq, yarada bilməyəcəklər",
    "Check out our blog" : "Bizim bloqa baxın",
    "Subscribe to our newsletter" : "Yeniliklərə abunə olun",
    "png or jpg, max. 20 MB" : "png vəya jpg, maksimum. 20 MB",
    "Your location" : "Sizin məkan",
    "Add a new user" : "Yeni istifadəçi əlavə edin",
    "Show Languages" : "Dilləri göstərin",
    "Send email to new user" : "Yeni istifadəçiyə məktub yolla",
    "Plain" : "Adi",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Authentication method" : "Qeydiyyat metodikası"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.9.tgz: nextcloud/apps/settings/l10n/az.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Gizli",
    "Local" : "Yerli",
    "Federated" : "Federated",
    "Published" : "Nəşr edilmiş",
    "Verify" : "Təsdiq et",
    "Verifying …" : "Təsdiqlənir ...",
    "Unable to change password" : "Şifrəni dəyişmək olmur",
    "Very weak password" : "Çox asan şifrə",
    "Weak password" : "Asan şifrə",
    "So-so password" : "Elə-belə şifrə",
    "Good password" : "Yaxşı şifrə",
    "Strong password" : "Çətin şifrə",
    "Groups" : "Qruplar",
    "Group list is empty" : "Qrup listi boşdur",
    "Your password was reset" : "Sizin parol yeniləndi",
    "You changed your email address" : "Siz email ünvanınızı dəyişdir",
    "Apps" : "Tətbiqlər",
    "Could not remove app." : "Tətbiqi silmək olmur.",
    "Could not update app." : "Tətbiqi yeniləmək alınmır",
    "Wrong password" : "Yalnış şifrə",
    "Unable to change personal password" : "Şəxsi parolu dəyişmək alınmadı",
    "Saved" : "Saxlanıldı",
    "No user supplied" : "Heç bir istifadəçiyə mənimsədilmir",
    "Unable to change password. Password too long." : "Parolu dəyişmək alınmadı. Parol çox uzundur.",
    "Authentication error" : "Təyinat metodikası",
    "Wrong admin recovery password. Please check the password and try again." : "İnzibatçı geriyə qayıdış şifrəsi yalnışdır. Xahiş olunur şifrəni yoxlayıb yenidən təkrar edəsiniz.",
    "Federated Cloud Sharing" : "Federal Cloud Paylaşım",
    "User documentation" : "İstifadəçi dokumentasiyası",
    "Invalid SMTP password." : "SMTP parol səhvdir",
    "Email setting test" : "Email parametrləriinin testi",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Məktubun yollanmasında səhv baş verdi. Xahiş olunur öz quraşdırmalarınıza yenidən göz yetirəsiniz.(Error: %s)",
    "Users" : "İstifadəçilər",
    "Invalid user" : "İstifadəçi adı yalnışdır",
    "Invalid mail address" : "Yalnış mail ünvanı",
    "Settings saved" : "Parametrlər yaddaşa verildi",
    "Unable to change full name" : "Tam adı dəyişmək olmur",
    "Your %s account was created" : "Sizin %s hesab yaradıldı",
    "Set your password" : "Parolunuzu təyin edin",
    "Install Client" : "Müştərini Quraşdır",
    "Settings" : "Quraşdırmalar",
    "Personal" : "Şəxsi",
    "Administration" : "İdarəetmə",
    "Additional settings" : "Əlavə parametrlər",
    "Overview" : "İcmal",
    "Basic settings" : "İlkin parametrlər",
    "Sharing" : "Paylaşılır",
    "Availability" : "Əlçatanlıq",
    "Calendar" : "Təqvim",
    "Personal info" : "Şəxsi məlumat",
    "Mobile & desktop" : "Mobil & Desktop",
    "Email server" : "Email server",
    "Security & setup warnings" : "Təhlükəsizlik & işə salma xəbərdarlıqları",
    "Background jobs" : "Background işlər",
    "Unlimited" : "Limitsiz",
    "Verifying" : "Təsdiqlənir",
    "Disabled" : "Dayandırılıb",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Server tərəfdən köhnə şifrələnmə formatı aktivdir. Onu söndürməyi tövsiyyə edirik.",
    "Supported" : "Dəstəklənir",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB \"%s\" versiyası istifadə edilir. Nextcloud 21 və yuxarı versiyaları bunu dəstəkləmir və ən azı MariaDB 10.2 və ya yuxarı versiya tələb edir.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL \"%s\" versiyası istifadə edilir. Nextcloud 21 və yuxarı versiyaları bunu dəstəkləmir və ən azı MySQL 8.0 və ya MariaDB 10.2 və ya yuxarı versiya tələb edir.",
    "Profile information" : "Profil məlumatı",
    "Nextcloud settings" : "Nextcloud parametrləri",
    "None" : "Heç bir",
    "Unable to modify setting" : "Xassələri yeniləmək olmadı",
    "Allow apps to use the Share API" : "Proqramlara izin verin ki, Paylaşım API-sindən istifadə edə bilsinlər.",
    "Allow resharing" : "Yenidən paylaşıma izin",
    "Restrict users to only share with users in their groups" : "İstifadəçiləri yalnız yerləşdikləri qrup üzvləri ilə paylaşım edə bilmələrini məhdudla",
    "Allow public uploads" : "Ümumi yüklənmələrə izin vermək",
    "Enforce password protection" : "Şifrə müdafiəsini həyata keçirmək",
    "Exclude groups from sharing" : "Qrupları paylaşımdan ayır",
    "These groups will still be able to receive shares, but not to initiate them." : "Bu qruplar paylaşımları hələdə ala biləcəklər ancaq, yarada bilməyəcəklər",
    "Enforce expiration date" : "Bitmə tarixini həyata keçir",
    "Two-Factor Authentication" : "İki faktorlu autentifikasiya",
    "Limit to groups" : "Qruplara limitlə",
    "Save changes" : "Dəyişiklikləri yaddaşa ver",
    "All" : "Hamısı",
    "Limit app usage to groups" : "Tətbiqin istifadəsini qruplar üçün limitlə",
    "No results" : "Nəticə yoxdur",
    "Update to {version}" : "{version} dək yenilə",
    "Remove" : "Sil",
    "Disable" : "Dayandır",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Bu proqram yüklənə bilməz ona görə ki, göstərilən asılılıqlar yerinə yetirilməyib:",
    "View in store" : "Dükanda bax",
    "Visit website" : "Sayta keç",
    "Report a bug" : "Səhv haqqında bildir",
    "Admin documentation" : "İdarəci dokumentasiyası",
    "Developer documentation" : "Yaradıcı sənədləşməsi",
    "Featured" : "Seçilmiş",
    "Name" : "Ad",
    "Version" : "Versiya",
    "Actions" : "İşlər",
    "No apps found for your version" : "Sizin versiya üçün proqram tapılmadı",
    "Device settings" : "Cihazın parametrləri",
    "Rename" : "Adı dəyiş",
    "Wipe device" : "Cihazı silin",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Android üçün Google Chrome",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOS tətbiq",
    "{productName} Android app" : "{productName} Android tətbiq",
    "{productName} Talk for iOS" : "{productName} iOS üçün danış",
    "{productName} Talk for Android" : "{productName} Android üçün danış",
    "This session" : "Bu sessiya",
    "Device" : "Cihaz",
    "Last activity" : "Son aktivlik",
    "Devices & sessions" : "Cihaz & sessiyalar",
    "Confirm wipe" : "Silməni təsdiq edin",
    "Error while updating device token name" : "Cihazın tokeninin adını yeniləyən vaxtı səhv baş verdi",
    "Error while deleting the token" : "Token silinən vaxtı səhv baş verdi",
    "App name" : "Tətbiqin adı",
    "Create new app password" : "Yeni tətbiq parolu yaradın",
    "Username" : "İstifadəçi adı",
    "Password" : "Şifrə",
    "Done" : "Edildi",
    "Show QR code for mobile apps" : "Mobil tətbiqlər üçün QR kodu göstərin",
    "Copied!" : "Kopyalandı!",
    "Copy" : "Kopyala",
    "Last job ran {relativeTime}." : "Son işin icra vaxtı {relativeTime}.",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (Tövsiyyə edilən)",
    "Profile" : "Profil",
    "Enable" : "İşə sal",
    "Cancel" : "Dayandır",
    "Rename group" : "Qrupun adını dəyiş",
    "Remove group" : "Qrupu sil",
    "Current password" : "Hazırkı şifrə",
    "New password" : "Yeni şifrə",
    "Change password" : "Şifrəni dəyiş",
    "Your profile information" : "Sizin profil məlumatlarınız",
    "Your profile picture" : "Sizin profil şəkliniz",
    "Upload profile picture" : "Profil şəklini yüklə",
    "Choose profile picture from Files" : "Profil şəklini Faylalrdan seçin",
    "Remove profile picture" : "Profil şəklini silin",
    "The file must be a PNG or JPG" : "Fayl PNG və ya JPG olmalıdır",
    "Set as profile picture" : "Profil şəkli kimi təyin et",
    "Please select a valid png or jpg file" : "Zəhmət olmasa düzgün png və ya jpg fayl seçin",
    "Error setting profile picture" : "Profil şəklini təyiin edən vaxtı səhv baş verdi",
    "Error saving profile picture" : "Profil şəklini saxlayan vaxtı səhv baş verdi",
    "Error removing profile picture" : "Profil şəklini silən vaxtı səhv baş verdi",
    "Details" : "Detallar",
    "No email address set" : "Email ünvanı dəsti yoxdur",
    "Help translate" : "Tərcüməyə kömək",
    "Add" : "Əlavə etmək",
    "Create" : "Yarat",
    "Change" : "Dəyiş",
    "Delete" : "Sil",
    "Email" : "Email",
    "Quota" : "Norma",
    "Language" : "Dil",
    "Edit" : "Dəyişiklik et",
    "Show user backend" : "Daxili istifadəçini göstər",
    "Send email" : "Email yolla",
    "Admins" : "İnzibatçılar",
    "Email sent" : "Məktub göndərildi",
    "Location" : "Yerləşdiyiniz ünvan",
    "Profile picture" : "Profil şəkli",
    "About" : "Haqqında",
    "Full name" : "Tam ad",
    "Updates" : "Yenilənmələr",
    "Hide" : "Gizlə",
    "Never" : "Heç vaxt",
    "Documentation" : "Sənədlər",
    "Forum" : "Forum",
    "Login" : "Giriş",
    "SSL" : "SSL",
    "Open documentation" : "Sənədləri aç",
    "Send mode" : "Göndərmə rejimi",
    "Encryption" : "Şifrələnmə",
    "From address" : "Ünvandan",
    "Server address" : "Server ünvanı",
    "Port" : "Port",
    "Authentication required" : "Qeydiyyat tələb edilir",
    "Credentials" : "Səlahiyyətlər",
    "SMTP Username" : "SMTP İstifadəçi adı",
    "SMTP Password" : "SMTP Şifrəsi",
    "Save" : "Saxla",
    "Check out our blog" : "Bizim bloqa baxın",
    "Subscribe to our newsletter" : "Yeniliklərə abunə olun",
    "png or jpg, max. 20 MB" : "png vəya jpg, maksimum. 20 MB",
    "Your email address" : "Sizin email ünvanı",
    "Your location" : "Sizin məkan",
    "Add a new user" : "Yeni istifadəçi əlavə edin",
    "Show Languages" : "Dilləri göstərin",
    "Send email to new user" : "Yeni istifadəçiyə məktub yolla",
    "Plain" : "Adi",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Authentication method" : "Qeydiyyat metodikası",
    "Set default expiration date" : "Susmaya görə olan bitmə vaxtını təyin edin"
},
"nplurals=2; plural=(n != 1);");
